@@ -15,8 +15,8 @@
 #' pre-commit with [use_precommit()] using the argument `config_source` to
 #' copy an existing config file into your repo. This argument defaults to the R
 #' option `precommit.config_source`, so you may want to set this option in
-#' your `.Rprofile` for convenience. Note that this is **not** equivalent
-#' to the `--config` option in the CLI command `pre-commit install` and similar,
+#' your `.Rprofile` for convenience. Note that this is **not** equivalent to the
+#' `--config` option in the CLI command `pre-commit install` and similar,
 #' which do *not* copy a config file into a project root (and allow to put it
 #' under version control), but rather link it in some more or less transparent
 #' way.
@@ -40,15 +40,15 @@ use_precommit_config <- function(config_source = getOption("precommit.config_sou
   )
   escaped_name_target <- "^\\.pre-commit-config\\.yaml$"
   name_target <- ".pre-commit-config.yaml"
-  if (!fs::file_exists(fs::path(root, name_target)) | force) {
+  if (!file_exists(fs::path(root, name_target)) | force) {
     fs::file_copy(
       config_source,
       fs::path(root, name_target),
       overwrite = TRUE
     )
-    usethis::ui_done("Copied .pre-commit-config.yaml to {root}")
+    cli::cli_alert_success("Copied .pre-commit-config.yaml to {root}")
   } else {
-    usethis::ui_info(paste0(
+    cli::cli_alert_info(paste0(
       "There is already a pre-commit configuration file in ",
       root,
       ". Use `force = TRUE` to replace .pre-commit-config.yaml."
@@ -56,16 +56,12 @@ use_precommit_config <- function(config_source = getOption("precommit.config_sou
   }
 
   if (is_package(root)) {
-    usethis::with_project(root, {
-      usethis::write_union(fs::path(root, ".Rbuildignore"), escaped_name_target)
-    })
+    write_union(fs::path(root, ".Rbuildignore"), escaped_name_target)
   }
-  usethis::ui_todo(c(
+  cli::cli_ul(c(
     "Edit .precommit-hooks.yaml to (de)activate the hooks you want to use. ",
-    "All available hooks: ",
-    "https://pre-commit.com/hooks.html",
-    "R specific hooks:",
-    "https://github.com/lorenzwalthert/precommit."
+    "All available hooks: https://pre-commit.com/hooks.html",
+    paste("R specific hooks:", hooks_repo)
   ))
   config_source
 }
@@ -82,7 +78,7 @@ set_config_source <- function(config_source,
                               verbose = TRUE) {
   if (is_url(config_source)) {
     if (verbose) {
-      usethis::ui_info("Downloading remote config from {config_source}.")
+      cli::cli_alert_info("Downloading remote config from {config_source}.")
     }
     tmp <- tempfile()
 
@@ -107,7 +103,7 @@ set_config_source <- function(config_source,
     )
     config_source <- system.file(name_origin, package = "precommit")
   }
-  if (!fs::file_exists(config_source)) {
+  if (!file_exists(config_source)) {
     rlang::abort(paste0(
       "File ", config_source, " does not exist. Please use the ",
       "argument `config_source` to provide a path to an existing ",
@@ -123,12 +119,12 @@ set_config_source <- function(config_source,
     ))
   }
   if (verbose) {
-    usethis::ui_info("Using local conifig from {config_source}.")
+    cli::cli_alert_info("Using local config from {config_source}.")
   }
   config_source
 }
 
 
 example_remote_config <- function() {
-  "https://raw.githubusercontent.com/lorenzwalthert/precommit/master/inst/pre-commit-config-proj.yaml"
+  "https://raw.githubusercontent.com/lorenzwalthert/precommit/main/inst/pre-commit-config-proj.yaml"
 }
