@@ -1,4 +1,29 @@
 install_system <- function(force) {
+  assert_reticulate_is_installed()
+  if (!is_installed() | force) {
+    cli::cli_alert_info(paste(
+      "Installing pre-commit into the conda environment",
+      "{.code r-precommit }."
+    ))
+    install_impl()
+    cli::cli_alert_success("Sucessfully installed pre-commit on your system.")
+    cli::cli_ul(
+      "To use it with this project, run `precommit::use_precommit()`"
+    )
+    path_exec <- path_derive_precommit_exec()
+    options(precommit.executable = path_exec)
+  } else {
+    path_exec <- path_precommit_exec(check_if_exists = FALSE)
+    cli::cli_alert_info(paste0(
+      "pre-commit already installed at the following locations:\n\n",
+      paste0("- ", path_exec), "\n\nUse `precommit::update_precommit()` to ",
+      "update the executable."
+    ))
+  }
+  invisible(path_exec)
+}
+
+assert_reticulate_is_installed <- function() {
   if (!rlang::is_installed("reticulate")) {
     rlang::abort(paste(
       "Please install the R package reticulate to use this installation",
@@ -6,35 +31,17 @@ install_system <- function(force) {
       "require reticulate. See https://lorenzwalthert.github.io/precommit."
     ))
   }
-  if (!is_installed() | force) {
-    usethis::ui_info(paste(
-      "Installing pre-commit into the conda environment",
-      "`r-precommit`."
-    ))
-    install_impl()
-    usethis::ui_done("Sucessfully installed pre-commit on your system.")
-    usethis::ui_todo(
-      "To use it with this project, run `precommit::use_precommit()`"
-    )
-    path_exec <- path_derive_precommit_exec()
-    options(precommit.executable = path_exec)
-  } else {
-    path_exec <- path_precommit_exec(check_if_exists = FALSE)
-    usethis::ui_info(c(
-      "pre-commit already installed at the following locations:",
-      paste0("- ", path_exec)
-    ))
-  }
-  invisible(path_exec)
 }
 
-#' Install pre-commit on your system.
+#' Install pre-commit on your system
 #'
 #' This installs pre-commit in the conda environment r-precommit. It
-#' will be available to use across different git repositories.
+#' will be available to use across different git repositories. To update,
+#' refer to [update_precommit()].
 #' @param force Whether or not to force a re-installation.
 #' @return
 #' The path to the pre-commit executable (invisibly).
+#' @family executable managers
 #' @examples
 #' \dontrun{
 #' install_precommit()
@@ -48,18 +55,34 @@ install_precommit <- function(force = FALSE) {
 #' @keywords internal
 install_impl <- function() {
   if (!"r-precommit" %in% reticulate::conda_list()$name) {
-    reticulate::conda_create("r-precommit")
+    reticulate::conda_create("r-precommit", python_version = "3.9")
   }
   reticulate::conda_install("r-precommit", packages = "pre-commit")
 }
 
+#' Updates pre-commit on your system with conda
+#' @keywords internal
+update_impl <- function() {
+  system2(
+    reticulate::conda_binary(), c(
+      "update", "--yes", "-n", "r-precommit",
+      "-c", "defaults", "-c", "conda-forge",
+      "pre-commit"
+    )
+  )
+}
+
 install_repo <- function(root, install_hooks, legacy_hooks) {
+  wait_for_hook_installation <- getOption(
+    "precommit.block_install_hooks", FALSE
+  )
   withr::with_dir(root, {
     remove_usethis_readme_hook()
     out <- call_precommit(
       "install",
       if (install_hooks) "--install-hooks",
-      if (legacy_hooks == "remove") "--overwrite"
+      if (legacy_hooks == "remove") "--overwrite",
+      wait = wait_for_hook_installation
     )
     if (out$exit_status == 0) {
       if (any(grepl("Use -f to use only pre-commit.", out$stdout, fixed = TRUE))) {
@@ -76,17 +99,25 @@ install_repo <- function(root, install_hooks, legacy_hooks) {
           ))
           call_precommit("uninstall")
         } else if (legacy_hooks == "allow") {
-          usethis::ui_done(paste(
+          cli::cli_alert_success(paste(
             "Sucessfully installed pre-commit for repo.",
-            "Existing hooks found and argument `allow_legacy = TRUE`. Running",
+            "Existing hooks found and argument {.code allow_legacy = TRUE }. Running",
             "in migration mode."
           ))
         }
       } else {
-        usethis::ui_done("Sucessfully installed pre-commit for repo.")
+        if (wait_for_hook_installation) {
+          cli::cli_alert_success("Sucessfully installed pre-commit for repo.")
+        } else {
+          cli::cli_alert_info(paste0(
+            "Installing hooks in non-blocking background process.",
+            " If you experience problems or prefer a blocking process, use ",
+            '{.code options("precommit.block_install_hooks" = TRUE)}.'
+          ))
+        }
       }
     } else {
-      usethis::ui_oops("Failed to install pre-commit for repo.")
+      cli::cli_alert_danger("Failed to install pre-commit for repo.")
       communicate_captured_call(out, preamble = "Problems during initialization:")
     }
   })
@@ -98,10 +129,10 @@ remove_usethis_readme_hook <- function() {
     encoding = "UTF-8"
   )
   candidate <- ".git/hooks/pre-commit"
-  if (fs::file_exists(candidate)) {
+  if (file_exists(candidate)) {
     if (identical(readLines(candidate, encoding = "UTF-8"), legacy)) {
       fs::file_delete(candidate)
-      usethis::ui_info(paste(
+      cli::cli_alert_info(paste(
         "Removed the render-README hook, which was added with",
         "`usethis::use_readme_rmd()` to this repo at some point in the past.",
         "{{precommit}}'s equivalent is the hook with the id 'readme-rmd-rendered'.",
@@ -126,6 +157,7 @@ remove_usethis_readme_hook <- function() {
 #' @inheritParams fallback_doc
 #' @return
 #' `NULL` (invisibly). The function is called for its side effects.
+#' @family executable managers
 #' @examples
 #' \dontrun{
 #' uninstall_precommit()
@@ -140,9 +172,9 @@ uninstall_precommit <- function(scope = "repo",
     if (scope == "repo") {
       uninstall_repo(ask = (ask %in% c("repo", "both")))
       path_config <- ".pre-commit-config.yaml"
-      if (fs::file_exists(path_config)) {
+      if (file_exists(path_config)) {
         fs::file_delete(path_config)
-        usethis::ui_done("Removed .pre-commit-config.yaml")
+        cli::cli_alert_success("Removed .pre-commit-config.yaml")
       }
     } else if (scope == "user") {
       uninstall_system(ask = (ask %in% c("user", "both")))
@@ -183,7 +215,7 @@ uninstall_system <- function(ask = TRUE) {
           "remove -n r-precommit pre-commit --yes"
         )
         if (out$exit_status == 0) {
-          usethis::ui_done("Removed pre-commit from conda env r-precommit.")
+          cli::cli_alert_success("Removed pre-commit from conda env r-precommit.")
         } else {
           communicate_captured_call(out)
         }
@@ -214,7 +246,7 @@ uninstall_repo <- function(ask) {
   if (continue) {
     out <- call_precommit("uninstall")
     if (out$exit_status == 0) {
-      usethis::ui_done("Uninstalled pre-commit from repo scope.")
+      cli::cli_alert_success("Uninstalled pre-commit from repo scope.")
     } else {
       communicate_captured_call(out)
     }
@@ -223,14 +255,14 @@ uninstall_repo <- function(ask) {
       precommit_hooks_idx <- which(lines == "^\\.pre-commit-config\\.yaml$")
       remaining <- rlang::seq2(1, length(lines)) %>% setdiff(precommit_hooks_idx)
       if (length(precommit_hooks_idx) > 0) {
-        usethis::ui_info("Removing .pre-commit-hooks.yaml from .Rbuildignore")
+        cli::cli_alert_info("Removing .pre-commit-hooks.yaml from .Rbuildignore")
         writeLines(enc2utf8(lines[remaining]), ".Rbuildignore")
       }
     }
     path_file <- ".pre-commit-config.yaml"
-    if (fs::file_exists(path_file)) {
+    if (file_exists(path_file)) {
       fs::file_delete(path_file)
-      usethis::ui_done(paste(
+      cli::cli_alert_success(paste(
         "Removed .pre-commit-config.yaml. If you want your collaborators",
         "to be able to\ncontinue to use pre-commit in this repo, you should",
         "undo the deletion of this file,\ne.g. with `$ git checkout",
@@ -238,15 +270,15 @@ uninstall_repo <- function(ask) {
       ))
     }
 
-    usethis::ui_info(paste(
+    cli::cli_alert_info(paste(
       "You can re-install pre-commit for this project at anytime with",
       "`precommit::use_precommit()`."
     ))
   } else {
-    usethis::ui_info("You did not type 'yes', uninstallation process aborted.")
+    cli::cli_alert_info("You did not type 'yes', uninstallation process aborted.")
   }
 }
 
 is_installed <- function() {
-  fs::file_exists(path_precommit_exec(check_if_exists = FALSE))
+  file_exists(path_precommit_exec(check_if_exists = FALSE))
 }
