@@ -94,7 +94,7 @@ release_complete <- function(ask = TRUE, is_cran = ask, tag = NULL) {
     }
     sys_call("git", glue::glue("push origin {tag}"))
   }
-  precommit::autoupdate() # only updates if tag is on the main branch
+  autoupdate() # only updates if tag is on the main branch
   desc::desc_bump_version("dev")
   cli::cli_alert_success("Bumped version to dev")
   sys_call("git", glue::glue('commit DESCRIPTION .pre-commit-config.yaml -m "use latest release"'),
